# Changelog

## [0.1.1](https://github.com/liblaf/avocado/compare/v0.1.0...v0.1.1) (2025-01-12)


### ✨ Features

* add serialization/deserialization utilities for JSON, TOML, YAML, and Pydantic ([6c2d06d](https://github.com/liblaf/avocado/commit/6c2d06d2296b814745b35bc361cdd8ec45513dff))

## 0.1.0 (2025-01-12)


### 👷 Build System

* initialize Python package with core functionality ([4d8db54](https://github.com/liblaf/avocado/commit/4d8db547bc10a29d0488bdb13307ccda0b22790e))


### 🔧 Continuous Integration

* update GitHub workflows and copier configuration ([1a65947](https://github.com/liblaf/avocado/commit/1a659472dd3d7fc228434b646c7c279e5187973d))
